/**
 * GMyth Library
 *
 * @file gmyth/gmyth_context.h
 * 
 * @brief <p> GMythContext class contains general attributes and functions
 * that express the connection state of each mythtvfrontend.
 *
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Hallyson Luiz de Morais Melo <hallyson.melo@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __GMYTH_CONTEXT_H__
#define __GMYTH_CONTEXT_H__

#include <glib-object.h>

#include "gmyth_settings.h"
#include "gmyth_socket.h"
#include "gmyth_stringlist.h"

G_BEGIN_DECLS

#define GMYTH_CONTEXT_TYPE               (gmyth_context_get_type ())
#define GMYTH_CONTEXT(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_CONTEXT_TYPE, GMythContext))
#define GMYTH_CONTEXT_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_CONTEXT_TYPE, GMythContextClass))
#define IS_GMYTH_CONTEXT(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_CONTEXT_TYPE))
#define IS_GMYTH_CONTEXT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_CONTEXT_TYPE))
#define GMYTH_CONTEXT_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GMYTH_CONTEXT_TYPE, GMythContextClass))

#define MYTHTV_VERSION_DEFAULT          30

typedef struct _GMythContext         GMythContext;
typedef struct _GMythContextClass    GMythContextClass;

struct _GMythContextClass
{
  GObjectClass parent_class;

  /* callbacks */
  /* no one for now */
};

struct _GMythContext
{
    GObject parent;

	GMythSettings *gmyth_settings;
	GMythSocket *server_socket;  
	
	GString *localhostname;
};


GType           gmyth_context_get_type (void);
void            gmyth_context_create();

gboolean gmyth_context_initialize ();
gboolean gmyth_context_check_connection ();
GMythSettings* gmyth_context_get_settings ();

gboolean gmyth_context_send_receive_stringlist (GMythStringList *strlist);

GString* gmyth_context_get_setting_onhost (GString *key, GString *host, GString *default_value);
gboolean gmyth_context_get_local_hostname (GString *hostname);

GString* gmyth_context_get_setting_onhost (GString *key, GString *host, GString *default_value);


G_END_DECLS

#endif /* __GMYTH_CONTEXT_H__ */
